@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015 cPanel, Inc.
+# Copyright (c) 2019 cPanel, L.L.C.
 # All rights reserved.
 # http://cpanel.net/
 #
@@ -36,8 +36,9 @@ sub run_client_tests ($@) {
         );
 
         my $client = OpenStack::Client->new($endpoint,
-            'package_ua'      => $ua,
-            'package_request' => 'Test::OpenStack::Client::Request'
+            'package_ua'       => $ua,
+            'package_request'  => 'Test::OpenStack::Client::Request',
+            'package_response' => 'Test::OpenStack::Client::Response'
         );
 
         $test->{'test'}->($client, $ua);
@@ -47,36 +48,31 @@ sub run_client_tests ($@) {
 }
 
 sub run_auth_tests ($@) {
-    my ($class, @tests) = @_;
+    my ($class, %args) = @_;
 
-    foreach my $test (@tests) {
-        my $endpoint    = $test->{'endpoint'}    || 'http://foo.bar/';
-        my $credentials = $test->{'credentials'} || {
-            'tenant'   => 'foo',
-            'username' => 'foo',
-            'password' => 'bar'
-        };
-
-        my @responses;
-
-        push @responses, map {
-            Test::OpenStack::Client::Response->new(%{$_})
-        } @{$test->{'responses'}} if defined $test->{'responses'};
-
-        unless (@responses) {
-            push @responses, Test::OpenStack::Client::Response->new;
-        }
+    my $endpoint    = 'http://foo.bar/';
+    my $credentials = {
+        'tenant'   => 'foo',
+        'username' => 'foo',
+        'password' => 'bar'
+    };
 
+    foreach my $test (@{$args{'tests'}}) {
         my $ua = Test::OpenStack::Client::UserAgent->generate(
-            'responses' => \@responses
+            'responses' => [Test::OpenStack::Client::Response->new(
+                'headers' => $args{'headers'},
+                'content' => $args{'content'}
+            )]
         );
 
         my $auth = OpenStack::Client::Auth->new($endpoint, %{$credentials},
-            'package_ua'      => $ua,
-            'package_request' => 'Test::OpenStack::Client::Request'
+            'version'          => $args{'version'},
+            'package_ua'       => $ua,
+            'package_request'  => 'Test::OpenStack::Client::Request',
+            'package_response' => 'Test::OpenStack::Client::Response'
         );
 
-        $test->{'test'}->($auth, $ua);
+        $test->($auth, $ua);
     }
 
     return;
